**********************************************************************************************************************************
*This code replicates the key tables (those presenting regression results) in "Information and Quality when Motivation is Intrinsic: Evidence from Surgeon Report Cards"*
*Running this code requires obtaining the CABG Claims Datasets for 1994-95, 2000, 2002 and 2003 from the Pennsylvania Health Care Cost Containment Council (http://www.phc4.org)
*For intermediate files I provide the steps neccessary to generate those files. This should allow someone who has obtained and
*understands the data to replicate each Table in the paper.
*Inquiries are welcome in this proces: jkolstad@wharton.upenn.edu
**********************************************************************************************************************************

******************************************************************************************************************
*Generating the choice file for the demand mode:

*	1.Generate a long file at the patient, surgeon choice level: This set has a variable named "cabgid" that is the surgeon identifier for the selected surgeon 
*	and "cabgid_" that is an alternative surgeon that could have been selected in that HRR
*	- If there are Z surgeries and N surgeons in an HRR there should be ZxN observations (with H HRRs this makes a larger number of obersvations)
*	2. Generate a variable equal to 1 if a surgeon is selected and label it "chosen"
*	3. Merge in measures of distance from a surgeons primary hospital (majority of surgeries) and patients home zip code centroid (done using ArcGIS)
*	- Mixed logit model will be estimated based on these data using the "mixlogit" command in Stata
*	4. Merge data on publications and citations of those publication. This can be generated by many university library services
* 	5. Generate a measure of RAMR for each surgeon at the quarter level and generate a lagged measure of RAMR for each surgeon for the prior quarter
*	6. Generate a variable equal to 1 if the ovbservation occurred after the release of the first report card (1998) but before the release of the second (prior to June 2002)
*	7. Generate a variable that is the deviation between each patients expected mortality rate and the mean expected mortality rate for all patient seen by the choice surgeon in the prior quarter 

*Tables 1 and 2 can be produced easily since they are summary stats

******************************************************************************************************************
*Regressions that generate results in Table 3
*Base model
mixlogit  chosen if date<170 & year>0, group(id) rand(cabgid_RAMR_lag cabgid_RAMR_lag_post9495  distance distance_post9495 distance_2 distance_2_post9495  below_ave_9495 below_ave_9495_post9495 above_ave_9495 above_ave_9495_post9495 not_rated_9495 not_rated_9495_post9495)   
*Model w/ agency/patient matching controls
mixlogit chosen  if date<170 & year>0, group(id) rand(cabgid_RAMR_lag cabgid_RAMR_lag_post9495 prior_q_dev_pred_m_i prior_q_dev_pred_m_i_post9495 prior_q_dev_pred_m_i_2 prior_q_dev_pred_m_i_2_post9495  distance distance_post9495 distance_2 distance_2_post9495  below_ave_9495 below_ave_9495_post9495 above_ave_9495 above_ave_9495_post9495 not_rated_9495 not_rated_9495_post9495)

*Use regression estimates from each time period to model volume with and without reporting in each period
*	1.Estimate the demand model above in 1994-95
*	2.Fit the parameter estimates in all years and save as pred_vol_pre
*	3.Estimate the demand model in 2000 and Q1,2 of 2002 (date<170)
*	4.Fit the parameter estimates in all years and save as pred_vol_post

*Generate OMR and RAMR estimates by each surgeon in 1994-95
*Generate a variable equal to the difference (OMR-RAMR)
*Generate quartiles q named new_info_quart"q"
*Generate a variable "change_RAMR_9495_00" equal to the change in the surgeon level mean RAMR between 1994-95 and 2000

******************************************************************************************************************

*Regressions that generate results in Table 4
*No market fixed effects, no control for baseline RAMR
bootstrap: reg change_RAMR_9495_00 new_info_quart1 new_info_quart2 new_info_quart4 new_info_quart5 mixvol_diff_prepost_full mixneg_dem_full mixneg_dem_vol_diff_prepost_full max_license_year max_license_year_2 max_publications max_publications_2 if date<170 & weight_surgeon_date==1 & ~missing(change_RAMR_9495_00), cluster(cabgid_year)
*No market fixed effects, includes baseline RAMR
bootstrap: reg change_RAMR_9495_00 new_info_quart1 new_info_quart2 new_info_quart4 new_info_quart5 mixvol_diff_prepost_full mixneg_dem_full mixneg_dem_vol_diff_prepost_full mean_RAMR_9495 max_license_year max_license_year_2 max_publications max_publications_2 if date<170  & weight_surgeon_date==1, cluster(cabgid_year)
*Market fixed effects, no control for baseline RAMR
bootstrap: areg change_RAMR_9495_00 new_info_quart1 new_info_quart2 new_info_quart4 new_info_quart5 mixvol_diff_prepost_full mixneg_dem_full mixneg_dem_vol_diff_prepost_full max_license_year max_license_year_2 max_publications max_publications_2 if date<170  & weight_surgeon_date==1, cluster(cabgid_year) absorb(hrrnum)
*Market fixed effects, includes baseline RAMR
bootstrap: areg change_RAMR_9495_00 new_info_quart1 new_info_quart2 new_info_quart4 new_info_quart5 mixvol_diff_prepost_full mixneg_dem_full mixneg_dem_vol_diff_prepost_full mean_RAMR_9495 max_license_year max_license_year_2 max_publications max_publications_2 if date<170  & weight_surgeon_date==1, cluster(cabgid_year) absorb(hrrnum)

******************************************************************************************************************
*Regressions that Generate Table 5

*Included in risk adjustment: cardiogenic shock (cshock), concurrent ptca (samedayptca), compicated hypertension (hyperwc), dialysis (dialysis), female (female)
* heart failure (failureh), prior cabg/valve surgery (hxcava)
*other risk scores: Atlas score (ASG), 
*note: female was not used as a RA in the 2000 report card and race/ethnicity was
*Unused observables: cardiomyopathy (cmyopthy),race (black), diabetes (diabetes), copd (copd), pvd, ob_cat, renal failure was used in 2000 but not in 1994-95 
*Generate measures of the share of patients with used/unused observables in 1994-95 and post report card.
*Generate changes in share of patients with used and unused risk adjusters for each surgeon between the periods

bootstrap: reg change_used_RA_9495_00 new_info_quart1 new_info_quart2 new_info_quart4 new_info_quart5 mixvol_diff_prepost_full mixneg_dem_full mixneg_dem_vol_diff_prepost_full max_license_year max_license_year_2 max_publications max_publications_2 if date<170 & weight_surgeon_date==1, cluster(cabgid_year)
bootstrap: reg change_used_RA_9495_00 new_info_quart1 new_info_quart2 new_info_quart4 new_info_quart5 mixvol_diff_prepost_full mixneg_dem_full mixneg_dem_vol_diff_prepost_full mean_RAMR_9495 max_license_year max_license_year_2 max_publications max_publications_2 if date<170 & weight_surgeon_date==1, cluster(cabgid_year)
bootstrap: reg change_unused_RA_9495_00 new_info_quart1 new_info_quart2 new_info_quart4 new_info_quart5 mixvol_diff_prepost_full mixneg_dem_full mixneg_dem_vol_diff_prepost_full max_license_year max_license_year_2 max_publications max_publications_2 if date<170 & weight_surgeon_date==1, cluster(cabgid_year)
bootstrap: reg change_unused_RA_9495_00 new_info_quart1 new_info_quart2 new_info_quart4 new_info_quart5 mixvol_diff_prepost_full mixneg_dem_full mixneg_dem_vol_diff_prepost_full mean_RAMR_9495 max_license_year max_license_year_2 max_publications max_publications_2 if date<170 & weight_surgeon_date==1, cluster(cabgid_year)



******************************************************************************************************************
*Regressions that Generate Table 6
*For each hospital generate mean RAMR for each surgeon in 1994-95
*For each surgeon generate variables equal to their RAMR minus the top and the bottom physician at their hospital (for multiple hospitals by surgeon assign the highest 1994-95 volume location)
*Save these variables as: "RAMR_relative_to_top" "RAMR_relative_to_bottom"

bootstrap: reg change_RAMR_9495_00 new_info_quart1 new_info_quart2 new_info_quart4 new_info_quart5 vol_diff_prepost_full neg_dem_full neg_dem_vol_diff_prepost_full mean_RAMR_9495 max_license_year max_license_year_2 max_publications max_publications_2 RAMR_relative_to_top RAMR_relative_to_bottom  if date<170 & weight_surgeon_date==1, cluster(cabgid_year) 
bootstrap: areg change_RAMR_9495_00 new_info_quart1 new_info_quart2 new_info_quart4 new_info_quart5 vol_diff_prepost_full neg_dem_full neg_dem_vol_diff_prepost_full mean_RAMR_9495 max_license_year max_license_year_2 max_publications max_publications_2 RAMR_relative_to_top RAMR_relative_to_bottom  if date<170 & weight_surgeon_date==1, cluster(cabgid_year) absorb(hrrnum) 

